@@ -115,7 +115,7 @@ async def build_enums(client: edgedb.AsyncIOClient, include_strawberry: bool) ->
         if not scalar.enum_values:
             continue
         enum_value_strs: T.List[str] = [
-            f'{e.replace(" ", "_").replace("-", "_")} = "{e}"'
+            f'{e.replace(" ", "_").replace("-", "_").replace(":", "_")} = "{e}"'
             for e in scalar.enum_values
         ]
         enum_value_str = "\n".join(enum_value_strs)
