@@ -588,6 +588,8 @@ for item in json_array_unpack(raw_data) union ({insert_str}) {given_resolver.to_
             description=f"only_one:{only_one}, {len_raw_d=}",
         ):
             if only_one:
+                if raw_d is None:
+                    return None
                 return parse_deleted(raw_d)
             else:
                 return [parse_deleted(d) for d in raw_d]
