@@ -610,7 +610,7 @@ class Resolver(BaseModel, T.Generic[NodeType]):
     async def gerror(
         self, *, given_client: edgedb.AsyncIOClient = None, merge: bool = True, **kwargs
     ) -> NodeType:
-        model = await self.get(merge=merge, **kwargs)
+        model = await self.get(given_client=given_client, merge=merge, **kwargs)
         if not model:
             raise ResolverException(f"No {self._model_name} in db with fields {kwargs}")
         return model
